#!/usr/bin/env bash

#set -e

export GRASS_OVERWRITE=1

PERF_PARAMS="-r 10"
BASENAME="test_rast_"

# just to make sure we use the default
unset GRASS_INT_ZLIB
unset GRASS_COMPRESSOR

r.mapcalc expression="test_rast_z_base = rand(double(-200.), 900)" seed=100

# writing

# none
echo "No compression writing"
echo "========================"
export GRASS_COMPRESSOR=NONE
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}none=double(${BASENAME}z_base)" > /dev/null

# RLE
echo "RLE compression writing"
echo "======================="
export GRASS_COMPRESSOR=RLE
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}rle=double(test_rast_z_base)" > /dev/null

# ZLIB
echo "ZLIB compression writing"
echo "======================="
export GRASS_COMPRESSOR=ZLIB
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}zlib=double(test_rast_z_base)" > /dev/null

# LZ4
echo "LZ4 compression writing"
echo "========================="
export GRASS_COMPRESSOR=LZ4
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}lz4=double(test_rast_z_base)" > /dev/null

# BZIP2
echo "BZIP2 compression writing"
echo "========================"
export GRASS_COMPRESSOR=BZIP2
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}bzip2=double(test_rast_z_base)" > /dev/null

# reading
echo "Original raster map test"
echo "========================"
perf stat $PERF_PARAMS r.univar test_rast_z_base > /dev/null
echo "No compression reading"
echo "========================"
perf stat $PERF_PARAMS r.univar ${BASENAME}none > /dev/null
echo "RLE compression reading"
echo "======================="
perf stat $PERF_PARAMS r.univar ${BASENAME}rle > /dev/null
echo "ZLIB compression reading"
echo "======================="
perf stat $PERF_PARAMS r.univar ${BASENAME}zlib > /dev/null
echo "LZ4 compression reading"
echo "========================="
perf stat $PERF_PARAMS r.univar ${BASENAME}lz4 > /dev/null
echo "BZIP2 compression reading"
echo "========================"
perf stat $PERF_PARAMS r.univar ${BASENAME}bzip2 > /dev/null

# check of types
echo "Check of types and compression"
echo "=============================="
r.compress -p ${BASENAME}z_base
r.compress -p ${BASENAME}none
r.compress -p ${BASENAME}rle
r.compress -p ${BASENAME}zlib
r.compress -p ${BASENAME}lz4
r.compress -p ${BASENAME}bzip2


# file sizes
echo "File sizes"
echo "=========="
ls -l `g.gisenv GISDBASE,LOCATION_NAME,MAPSET sep=/`/fcell/${BASENAME}*
ls -l `g.gisenv GISDBASE,LOCATION_NAME,MAPSET sep=/`/cell_misc/${BASENAME}*/null*
