"""
TEST:    test_r_compress.py

AUTHOR(S): Seth Price <seth at planet.com>

PURPOSE:   Test r.compress

COPYRIGHT: (C) 2015 Seth Price

           This program is free software under the GNU General Public
           License (>=v2). Read the file COPYING that comes with GRASS
           for details.
"""

import os

from grass.gunittest.case import TestCase
from grass.gunittest.main import test
from grass.gunittest.gmodules import SimpleModule


class TestBasicOperations(TestCase):

    # TODO: replace by unified handing of maps
    to_remove = []

    @classmethod
    def setUpClass(cls):
        cls.use_temp_region()
        cls.runModule('g.region', raster='elevation')
        os.environ.pop('GRASS_INT_ZLIB', None)
        os.environ.pop('GRASS_INT_LZ4', None)
        os.environ.pop('GRASS_INT_LZ4HC', None)
        os.environ.pop('GRASS_INT_ZSTD', None)

    @classmethod
    def tearDownClass(cls):
        cls.del_temp_region()
        if cls.to_remove:
            cls.runModule('g.remove', flags='f', type='raster',
                          name=','.join(cls.to_remove), verbose=True)

    def test_zlib_cell(self):
        """Test ZLIB & CELL"""
        self.run_comp_test('zlib', 'int', 'CELL')

    def test_zlib_fcell(self):
        """Test ZLIB & FCELL"""
        self.run_comp_test('zlib', 'float', 'FCELL')

    def test_zlib_dcell(self):
        """Test ZLIB & DCELL"""
        self.run_comp_test('zlib', 'double', 'DCELL')

    def test_lz4_cell(self):
        """Test LZ4 & CELL"""
        self.run_comp_test('lz4', 'int', 'CELL')

    def test_lz4_fcell(self):
        """Test LZ4 & FCELL"""
        self.run_comp_test('lz4', 'float', 'FCELL')

    def test_lz4_dcell(self):
        """Test LZ4 & DCELL"""
        self.run_comp_test('lz4', 'double', 'DCELL')

    def test_lz4hc_cell(self):
        """Test LZ4 & CELL"""
        self.run_comp_test('lz4hc', 'int', 'CELL')

    def test_lz4hc_fcell(self):
        """Test LZ4 & FCELL"""
        self.run_comp_test('lz4hc', 'float', 'FCELL')

    def test_lz4hc_dcell(self):
        """Test LZ4 & DCELL"""
        self.run_comp_test('lz4hc', 'double', 'DCELL')

    def test_zstd_cell(self):
        """Test ZSTD & CELL"""
        self.run_comp_test('zstd', 'int', 'CELL')

    def test_zstd_fcell(self):
        """Test ZSTD & FCELL"""
        self.run_comp_test('zstd', 'float', 'FCELL')

    def test_zstd_dcell(self):
        """Test ZSTD & DCELL"""
        self.run_comp_test('zstd', 'double', 'DCELL')

    def run_comp_test(self, comp_type, data_type, data_name):
        fname = 'elv_%s_%s' % (data_type, comp_type)
        env_var = 'GRASS_INT_%s' % comp_type.upper()

        os.environ[env_var] = '1'
        self.runModule('r.mapcalc',
                       expression='%s=%s(elevation)' % (fname, data_type))
        self.to_remove.append(fname)
        os.environ.pop(env_var, None)

        self.assertRastersNoDifference('elevation', fname, 1.0)

        module = SimpleModule('r.compress', flags='p', map=fname)
        self.assertModule(module)
        stdout = module.outputs.stderr

        self.assertIn(fname, stdout)
        if (comp_type == 'zlib'):
            self.assertIn('DEFLATE', stdout)
        else:
            self.assertIn(comp_type.upper(), stdout)
        self.assertIn(data_name, stdout)


if __name__ == '__main__':
    test()
