#!/usr/bin/env bash

export GRASS_OVERWRITE=1

PERF_PARAMS="-r 10"
BASENAME="test_rast_"

# just to make sure we use the default
unset GRASS_INT_ZLIB
unset GRASS_INT_LZ4
unset GRASS_INT_LZ4HC
unset GRASS_INT_ZSTD

r.mapcalc expression="test_rast_z_base = rand(double(-200.), 900)" seed=100

# writing

# default
echo "ZLIB compression writing"
echo "========================"
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}orig=double(${BASENAME}z_base)" > /dev/null

# RLE
echo "RLE compression writing"
echo "======================="
export GRASS_INT_ZLIB=0
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}rle=double(test_rast_z_base)" > /dev/null
unset GRASS_INT_ZLIB

# LZ4
echo "LZ4 compression writing"
echo "======================="
export GRASS_INT_LZ4=1
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}lz4=double(test_rast_z_base)" > /dev/null
unset GRASS_INT_LZ4

# LZ4HC
echo "LZ4HC compression writing"
echo "========================="
export GRASS_INT_LZ4HC=1
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}lz4hc=double(test_rast_z_base)" > /dev/null
unset GRASS_INT_LZ4HC

# ZSTD
echo "ZSTD compression writing"
echo "========================"
export GRASS_INT_ZSTD=1
perf stat $PERF_PARAMS r.mapcalc expression="${BASENAME}zstd=double(test_rast_z_base)" > /dev/null
unset GRASS_INT_ZSTD

# reading
echo "Original raster map test"
echo "========================"
perf stat $PERF_PARAMS r.univar test_rast_z_base > /dev/null
echo "ZLIB compression reading"
echo "========================"
perf stat $PERF_PARAMS r.univar ${BASENAME}orig > /dev/null
echo "RLE compression reading"
echo "======================="
perf stat $PERF_PARAMS r.univar ${BASENAME}rle > /dev/null
echo "LZ4 compression reading"
echo "======================="
perf stat $PERF_PARAMS r.univar ${BASENAME}lz4 > /dev/null
echo "LZ4HC compression reading"
echo "========================="
perf stat $PERF_PARAMS r.univar ${BASENAME}lz4hc > /dev/null
echo "ZSTD compression reading"
echo "========================"
perf stat $PERF_PARAMS r.univar ${BASENAME}zstd > /dev/null

# check of types
echo "Check of types and compression"
echo "=============================="
r.compress -p ${BASENAME}z_base
r.compress -p ${BASENAME}orig
r.compress -p ${BASENAME}rle
r.compress -p ${BASENAME}lz4
r.compress -p ${BASENAME}lz4hc
r.compress -p ${BASENAME}zstd


# file sizes
echo "File sizes"
echo "=========="
ls -l `g.gisenv GISDBASE,LOCATION_NAME,MAPSET sep=/`/fcell/${BASENAME}*
ls -l `g.gisenv GISDBASE,LOCATION_NAME,MAPSET sep=/`/cell_misc/${BASENAME}*/null*
